@@ -1,5 +1,6 @@
 import datetime as dt
-from pythonjsonlogger.jsonlogger import JsonFormatter
+from enum import Enum
+from pythonjsonlogger.jsonlogger import JsonFormatter, JsonEncoder
 
 
 class JSON(JsonFormatter):
@@ -11,6 +12,7 @@ class JSON(JsonFormatter):
             if field not in kwargs:
                 raise ValueError(f"Logging configuration requires field '{field}'")
             setattr(self, field, kwargs.pop(field))
+        kwargs["json_encoder"] = kwargs.get("json_encoder", CustomEncoder)
         super().__init__(*args, **kwargs)
 
     def add_fields(self, log_record, record, message_dict):
@@ -25,3 +27,10 @@ class JSON(JsonFormatter):
             log_record["level"] = record.levelname
         for field in self._FIXED_FIELDS:
             log_record[field] = getattr(self, field)
+
+
+class CustomEncoder(JsonEncoder):
+    def default(self, obj):  # pylint: disable=method-hidden
+        if isinstance(obj, Enum):
+            return obj.value
+        return JsonEncoder.default(self, obj)
